pub(crate) struct CharacterAndTrieValue {
pub(crate) character: char,
pub(crate) trie_val: u32,
}Expand description
Struct for holding together a character and the value looked up for it from the NFD trie in a more explicit way than an anonymous pair. Also holds a flag about the supplementary-trie provenance.
Fields
character: chartrie_val: u32See trie-value-format.md
Implementations
Sourceimpl CharacterAndTrieValue
impl CharacterAndTrieValue
pub fn new(c: char, trie_value: u32) -> Self
pub fn starter_and_decomposes_to_self(&self) -> bool
Sourcepub fn can_combine_backwards(&self) -> bool
pub fn can_combine_backwards(&self) -> bool
See trie-value-format.md
Sourcepub fn potential_passthrough(&self) -> bool
pub fn potential_passthrough(&self) -> bool
See trie-value-format.md